pitchtools.Accidental
=====================

.. inheritance-diagram:: abjad.tools.pitchtools.Accidental.Accidental.Accidental
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.Accidental.Accidental.Accidental

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.alphabetic_accidental_abbreviation

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.format

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.is_adjusted

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.name

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.semitones

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.symbolic_accidental_string

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__add__

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__eq__

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__ge__

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__gt__

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__le__

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__lt__

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__ne__

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__neg__

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__nonzero__

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__repr__

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__str__

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.Accidental.__sub__
